# ATLAS example

[ATLAS](https://atlas.cern/) is one of the Large Hadron Collider
([LHC](https://home.cern/science/accelerators/large-hadron-collider))
experiments at [CERN](https://home.cern/). It is a general-purpose detector, and
has been used to discover the Higgs boson, and to search for new physics beyond
the Standard Model.

```{note}
Interested in contributing? Head to the [GitHub repository](https://github.com/FAST-HEP/fasthep-flow) and open a pull request!
```
